from typing import Any
from .path import Path
import json


class JsonConfig:
    def __init__(self, name: str) -> None:
        self.config = json.loads(~Path(name))

    def __getitem__(self, items):
        if not isinstance(items, tuple):
            items = items,
        value = self.config
        for i in items:
            value = value[i]
        return value



from setuptools import setup, find_packages

setup(
    name="gochocolatego",
    version="1.2",
    packages=find_packages(),
    install_requires=[
        "rich"
    ],
    entry_points={
        "console_scripts": [
            "chocolate=chocolate.__main__:main",
        ],
    },
    author="Chocolateisfr",
    description="A project manager CLI tool.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/frchocolate/chocolate",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)
